pub struct Database {
db: Database,
}Expand description
The database
Fields
db: DatabaseImplementations
Sourceimpl Database
impl Database
Sourcepub async fn store_get<P, K, V>(&self, prefix: P, key: K) -> Result<Option<V>>
pub async fn store_get<P, K, V>(&self, prefix: P, key: K) -> Result<Option<V>>
Get a key from the store
Sourcepub async fn store_put<P, K, V>(
&self,
prefix: P,
key: K,
value: V,
) -> Result<()>
pub async fn store_put<P, K, V>( &self, prefix: P, key: K, value: V, ) -> Result<()>
Put a key in the store
Sourcepub async fn store_update<P, K, V, U>(
&self,
prefix: P,
key: K,
update_func: U,
) -> Result<()>
pub async fn store_update<P, K, V, U>( &self, prefix: P, key: K, update_func: U, ) -> Result<()>
Get and Put a key in the store in one action, ensuring the key is not changed between the commands.
Sourceimpl Database
impl Database
Sourcepub async fn create_tic_tac_toe_game(
&self,
guild_id: MaybeGuildString,
author: TicTacToePlayer,
author_team: Team,
opponent: TicTacToePlayer,
) -> Result<TicTacToeGame, TicTacToeCreateGameError>
pub async fn create_tic_tac_toe_game( &self, guild_id: MaybeGuildString, author: TicTacToePlayer, author_team: Team, opponent: TicTacToePlayer, ) -> Result<TicTacToeGame, TicTacToeCreateGameError>
Create a new tic-tac-toe game
Sourcepub async fn try_tic_tac_toe_move(
&self,
guild_id: MaybeGuildString,
player: TicTacToePlayer,
move_index: u8,
) -> Result<TicTacToeTryMoveResponse, TicTacToeTryMoveError>
pub async fn try_tic_tac_toe_move( &self, guild_id: MaybeGuildString, player: TicTacToePlayer, move_index: u8, ) -> Result<TicTacToeTryMoveResponse, TicTacToeTryMoveError>
Try to make a tic-tac-toe move
Sourcepub async fn get_tic_tac_toe_game(
&self,
guild_id: MaybeGuildString,
player: TicTacToePlayer,
) -> Result<Option<TicTacToeGame>>
pub async fn get_tic_tac_toe_game( &self, guild_id: MaybeGuildString, player: TicTacToePlayer, ) -> Result<Option<TicTacToeGame>>
Try to get a tic-tac-toe game by guild and player
Sourcepub async fn concede_tic_tac_toe_game(
&self,
guild_id: MaybeGuildString,
player: UserId,
) -> Result<Option<TicTacToeGame>>
pub async fn concede_tic_tac_toe_game( &self, guild_id: MaybeGuildString, player: UserId, ) -> Result<Option<TicTacToeGame>>
Sourcepub async fn get_tic_tac_toe_score(
&self,
guild_id: MaybeGuildString,
player: UserId,
) -> Result<TicTacToeScore>
pub async fn get_tic_tac_toe_score( &self, guild_id: MaybeGuildString, player: UserId, ) -> Result<TicTacToeScore>
Get the user’s Tic-Tac-Toe scores
Sourcepub async fn get_top_tic_tac_toe_scores(
&self,
guild_id: MaybeGuildString,
) -> Result<Vec<TicTacToeTopPlayerScore>>
pub async fn get_top_tic_tac_toe_scores( &self, guild_id: MaybeGuildString, ) -> Result<Vec<TicTacToeTopPlayerScore>>
Get the top Tic-Tac-Toe scores for the current server
Sourceimpl Database
impl Database
Sourcepub async fn set_tiktok_embed_flags(
&self,
guild_id: GuildId,
set_flags: TikTokEmbedFlags,
unset_flags: TikTokEmbedFlags,
) -> Result<(TikTokEmbedFlags, TikTokEmbedFlags)>
pub async fn set_tiktok_embed_flags( &self, guild_id: GuildId, set_flags: TikTokEmbedFlags, unset_flags: TikTokEmbedFlags, ) -> Result<(TikTokEmbedFlags, TikTokEmbedFlags)>
Set the flags for tiktok embeds.
Returns
Returns the old flags and new flags in a tuple in that order.
Sourcepub async fn get_tiktok_embed_flags(
&self,
guild_id: GuildId,
) -> Result<TikTokEmbedFlags>
pub async fn get_tiktok_embed_flags( &self, guild_id: GuildId, ) -> Result<TikTokEmbedFlags>
Get the tiktok embed flags.
Sourceimpl Database
impl Database
Sourcepub async unsafe fn new<P>(path: P, create_if_missing: bool) -> Result<Self>where
P: Into<Utf8PathBuf>,
pub async unsafe fn new<P>(path: P, create_if_missing: bool) -> Result<Self>where
P: Into<Utf8PathBuf>,
Safety
This must be called before any other sqlite functions are called.
Sourcepub unsafe fn blocking_new<P>(path: P, create_if_missing: bool) -> Result<Self>where
P: AsRef<Utf8Path>,
pub unsafe fn blocking_new<P>(path: P, create_if_missing: bool) -> Result<Self>where
P: AsRef<Utf8Path>,